@@ -62,10 +62,9 @@ int pth_key_setdata(pth_key_t key, const void *value)
     if (!pth_keytab[key].used)
         return_errno(FALSE, EINVAL);
     if (pth_current->data_value == NULL) {
-        pth_current->data_value = (const void **)malloc(sizeof(void *)*PTH_KEY_MAX);
+        pth_current->data_value = (const void **)calloc(1, sizeof(void *)*PTH_KEY_MAX);
         if (pth_current->data_value == NULL)
             return_errno(FALSE, ENOMEM);
-        memset((void *)pth_current->data_value, 0, sizeof(void *)*PTH_KEY_MAX);
     }
     if (pth_current->data_value[key] == NULL) {
         if (value != NULL)
