@@ -154,6 +154,12 @@ intern void pth_pqueue_delete(pth_pqueue_t *q, pth_t t)
     return;
 }
 
+/* determine priority required to favorite a thread */
+#if cpp
+#define pth_pqueue_favorite_prio(q) \
+    ((q)->q_head != NULL ? (q)->q_head->q_prio + 1 : PTH_PRIO_MAX)
+#endif
+
 /* move a thread inside queue to the top */
 intern int pth_pqueue_favorite(pth_pqueue_t *q, pth_t t)
 {
@@ -166,7 +172,7 @@ intern int pth_pqueue_favorite(pth_pqueue_t *q, pth_t t)
         return TRUE; 
     /* move to top */
     pth_pqueue_delete(q, t);
-    pth_pqueue_insert(q, q->q_head->q_prio+1, t);
+    pth_pqueue_insert(q, pth_pqueue_favorite_prio(q), t);
     return TRUE;
 }
 
@@ -183,20 +189,16 @@ intern void pth_pqueue_increase(pth_pqueue_t *q)
 }
 
 /* return number of elements in priority queue: O(1) */
-intern int pth_pqueue_elements(pth_pqueue_t *q)
-{
-    if (q == NULL)
-        return -1;
-    return q->q_num;
-}
+#if cpp
+#define pth_pqueue_elements(q) \
+    ((q) == NULL ? (-1) : (q)->q_num)
+#endif
 
 /* walk to first thread in queue */
-intern pth_t pth_pqueue_head(pth_pqueue_t *q)
-{
-    if (q == NULL)
-        return NULL;
-    return q->q_head;
-}
+#if cpp
+#define pth_pqueue_head(q) \
+    ((q) == NULL ? NULL : (q)->q_head)
+#endif
 
 /* walk to next or previous thread in queue */
 intern pth_t pth_pqueue_walk(pth_pqueue_t *q, pth_t t, int direction)
