@@ -99,27 +99,26 @@ int main(int argc, char *argv[])
     fprintf(stderr, "\n");
 
     fprintf(stderr, "Main Startup (%ld total threads running)\n", pth_ctrl(PTH_CTRL_GETTHREADS));
-    pth_nonblocking(STDIN_FILENO);
 
     t_attr = pth_attr_new();
     pth_attr_set(t_attr, PTH_ATTR_JOINABLE, FALSE);
     pth_attr_set(t_attr, PTH_ATTR_NAME, "foo");
-    child[0] = pth_spawn(t_attr, my_child, "foo");
+    child[0] = pth_spawn(t_attr, my_child, (void *)"foo");
     pth_attr_set(t_attr, PTH_ATTR_NAME, "bar");
-    child[1] = pth_spawn(t_attr, my_child, "bar");
+    child[1] = pth_spawn(t_attr, my_child, (void *)"bar");
     pth_attr_set(t_attr, PTH_ATTR_NAME, "baz");
-    child[2] = pth_spawn(t_attr, my_child, "baz");
+    child[2] = pth_spawn(t_attr, my_child, (void *)"baz");
     pth_attr_set(t_attr, PTH_ATTR_NAME, "quux");
-    child[3] = pth_spawn(t_attr, my_child, "quux");
+    child[3] = pth_spawn(t_attr, my_child, (void *)"quux");
     pth_attr_set(t_attr, PTH_ATTR_NAME, "killer");
     pth_attr_set(t_attr, PTH_ATTR_PRIO, 4);
-    child[4] = pth_spawn(t_attr, my_child, "killer");
+    child[4] = pth_spawn(t_attr, my_child, (void *)"killer");
     pth_attr_set(t_attr, PTH_ATTR_NAME, "killer II");
     pth_attr_set(t_attr, PTH_ATTR_PRIO, 5);
-    child[5] = pth_spawn(t_attr, my_child, "killer II");
+    child[5] = pth_spawn(t_attr, my_child, (void *)"killer II");
     pth_attr_set(t_attr, PTH_ATTR_NAME, "reader");
     pth_attr_set(t_attr, PTH_ATTR_PRIO, PTH_PRIO_STD);
-    child[6] = pth_spawn(t_attr, my_reader, "reader");
+    child[6] = pth_spawn(t_attr, my_reader, (void *)"reader");
     pth_attr_destroy(t_attr);
 
     t_attr2 = pth_attr_of(child[0]);
